@@ -315,13 +315,13 @@ def aborttran(autocommit = True):
 #
 # record error message to dscheck record and clean the lock
 #
-def record_dscheck_error(errmsg):
+def record_dscheck_error(errmsg, logact = PGDBI['EXITLG']):
 
    cnd = PgLOG.PGLOG['DSCHECK']['chkcnd']
    if PgLOG.PGLOG['NOQUIT']: PgLOG.PGLOG['NOQUIT'] = 0
    dflags = PgLOG.PGLOG['DSCHECK']['dflags']
 
-   pgrec = pgget("dscheck", "mcount, tcount, lockhost, pid", cnd, PgLOG.LGEREX)
+   pgrec = pgget("dscheck", "mcount, tcount, lockhost, pid", cnd, logact)
    if not pgrec: return 0
    if not pgrec['pid'] and not pgrec['lockhost']: return 0
    (chost, cpid) = PgLOG.current_process_info()
@@ -330,8 +330,9 @@ def record_dscheck_error(errmsg):
    # update dscheck record only if it is still locked by the current process
    record = {}
    record['chktime'] = int(time.time())
-   record['status'] = "E"
-   record['pid'] = 0   # release lock
+   if logact&PgLOG.EXITLG:
+      record['status'] = "E"
+      record['pid'] = 0   # release lock
    if dflags:
       record['dflags'] = dflags
       record['mcount'] = pgrec['mcount'] + 1
@@ -343,7 +344,7 @@ def record_dscheck_error(errmsg):
       if pgrec['tcount'] > 1: errmsg = "Try {}: {}".format(pgrec['tcount'], errmsg)
       record['errmsg'] = errmsg
 
-   return pgupdt("dscheck", record, cnd, PGDBI['ERRLOG'])
+   return pgupdt("dscheck", record, cnd, logact)
 
 #
 # local function to log query error
@@ -367,7 +368,7 @@ def qelog(dberror, sleep, sqlstr, vals, pgcnt, logact = PGDBI['ERRLOG']):
    if vals: sqlstr += " with values: " + str(vals)
 
    if dberror: sqlstr = "{}\n{}".format(dberror, sqlstr)
-   if logact&PgLOG.EXITLG and PgLOG.PGLOG['DSCHECK']: record_dscheck_error(sqlstr)
+   if logact&PgLOG.EXITLG and PgLOG.PGLOG['DSCHECK']: record_dscheck_error(sqlstr, logact)
    PgLOG.pglog(sqlstr, logact)
    if sleep: time.sleep(sleep)
 
@@ -1845,9 +1846,9 @@ def get_specialist(dsid, logact = PGDBI['ERRLOG']):
 #
 def build_customized_email(table, field, condition, subject, logact = 0):
 
+   estat = PgLOG.FAILURE
    msg = PgLOG.get_email()
-   
-   if not msg: return PgLOG.FAILURE
+   if not msg: return estat
    
    sender = PgLOG.PGLOG['CURUID'] + "@ucar.edu"
    receiver = PgLOG.PGLOG['EMLADDR'] if PgLOG.PGLOG['EMLADDR'] else (PgLOG.PGLOG['CURUID'] + "@ucar.edu")
@@ -1857,9 +1858,12 @@ def build_customized_email(table, field, condition, subject, logact = 0):
    if not subject: subject = "Message from {}-{}".format(PgLOG.PGLOG['HOSTNAME'], PgLOG.get_command())
    ebuf += "Subject: {}!\n\n{}\n".format(subject, msg)
 
-   estat = cache_customized_email(table, field, condition, ebuf, logact)
-   if estat and logact:
-      PgLOG.pglog("Email {} cached to '{}.{}' for {}, Subject: {}".format(receiver, table, field, condition, subject), logact)
+   if PgLOG.PGLOG['EMLSEND']:
+      estat = PgLOG.send_customized_email(f"{table}.{condition}", ebuf, logact)
+   if estat != PgLOG.SUCCESS:
+      estat = cache_customized_email(table, field, condition, ebuf, 0)
+      if estat and logact:
+         PgLOG.pglog("Email {} cached to '{}.{}' for {}, Subject: {}".format(receiver, table, field, condition, subject), logact)
 
    return estat
 
@@ -1924,7 +1928,7 @@ def cache_customized_email(table, field, condition, emlmsg, logact = 0):
       return PgLOG.SUCCESS
    else:
       msg = "cache email to '{}.{}' for {}".format(table, field, condition)
-      PgLOG.pglog("Error msg, try to send directly now", logact|PgLOG.ERRLOG)
+      PgLOG.pglog(f"Error {msg}, try to send directly now", logact|PgLOG.ERRLOG)
       return PgLOG.send_customized_email(msg, emlmsg, logact)
 
 #
